Package: ModelMetrics
Title: Rapid Calculation of Model Metrics
Version: 1.2.2.2
Date: 2018-11-03
Authors@R: person("Tyler", "Hunt", email = "thunt@snapfinance.com", role = c("aut", "cre"))
Description: Collection of metrics for evaluating models written in C++ using 'Rcpp'. Popular metrics include area under the curve, log loss, root mean square error, etc.
Depends: R (>= 3.2.2)
License: GPL (>= 2)
Encoding: UTF-8
LazyData: true
LinkingTo: Rcpp
Imports: Rcpp, data.table
RoxygenNote: 6.0.1
Suggests: testthat
NeedsCompilation: yes
Packaged: 2020-03-17 06:58:01 UTC; ripley
Author: Tyler Hunt [aut, cre]
Maintainer: Tyler Hunt <thunt@snapfinance.com>
Repository: CRAN
Date/Publication: 2020-03-17 07:45:31 UTC
Built: R 4.4.0; amd64-portbld-midnightbsd4; 2026-07-19 01:12:40 UTC; unix
