# Generated by roxygen2: do not edit by hand

S3method(auc,default)
S3method(auc,gbm)
S3method(auc,glm)
S3method(auc,glmerMod)
S3method(auc,randomForest)
S3method(auc,rpart)
S3method(brier,default)
S3method(brier,gbm)
S3method(brier,glm)
S3method(brier,glmerMod)
S3method(brier,randomForest)
S3method(brier,rpart)
S3method(ce,default)
S3method(ce,gbm)
S3method(ce,glm)
S3method(ce,glmerMod)
S3method(ce,lm)
S3method(ce,randomForest)
S3method(ce,rpart)
S3method(gini,default)
S3method(gini,gbm)
S3method(gini,glm)
S3method(gini,glmerMod)
S3method(gini,randomForest)
S3method(gini,rpart)
S3method(logLoss,default)
S3method(logLoss,gbm)
S3method(logLoss,glm)
S3method(logLoss,glmerMod)
S3method(logLoss,randomForest)
S3method(logLoss,rpart)
S3method(mae,default)
S3method(mae,gbm)
S3method(mae,glm)
S3method(mae,glmerMod)
S3method(mae,randomForest)
S3method(mae,rpart)
S3method(mse,default)
S3method(mse,glm)
S3method(mse,lm)
S3method(msle,default)
S3method(msle,gbm)
S3method(msle,glm)
S3method(msle,glmerMod)
S3method(msle,lm)
S3method(msle,randomForest)
S3method(msle,rpart)
S3method(rmse,default)
S3method(rmse,glm)
S3method(rmse,lm)
S3method(rmsle,default)
S3method(rmsle,gbm)
S3method(rmsle,glm)
S3method(rmsle,glmerMod)
S3method(rmsle,lm)
S3method(rmsle,randomForest)
S3method(rmsle,rpart)
export(auc)
export(brier)
export(ce)
export(confusionMatrix)
export(f1Score)
export(fScore)
export(gini)
export(kappa)
export(logLoss)
export(mae)
export(mauc)
export(mcc)
export(mlogLoss)
export(mse)
export(msle)
export(npv)
export(ppv)
export(precision)
export(recall)
export(rmse)
export(rmsle)
export(sensitivity)
export(specificity)
export(tnr)
export(tpr)
importFrom(Rcpp,sourceCpp)
importFrom(data.table,frankv)
importFrom(data.table,fsort)
importFrom(stats,predict)
useDynLib(ModelMetrics)
